@@ -1,9 +1,10 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004, 
+   2007 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Mailutils is distributed in the hope that it will be useful,
@@ -13,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /*
   GSSAPI authentication for imap (rfc 1731). 
@@ -23,9 +25,21 @@
 
 #include <netinet/in.h>
 
-#include <krb5.h>
-#include <gssapi/gssapi.h>
-#include <gssapi/gssapi_generic.h>
+#ifdef WITH_GSS
+# include <gss.h>
+#else
+# include <krb5.h>
+# ifdef HAVE_GSSAPI_H
+#  include <gssapi.h>
+# else
+#  ifdef HAVE_GSSAPI_GSSAPI_H
+#   include <gssapi/gssapi.h>
+#  endif
+#  ifdef HAVE_GSSAPI_GSSAPI_GENERIC_H
+#   include <gssapi/gssapi_generic.h>
+#  endif
+# endif
+#endif
 
 #define GSS_AUTH_P_NONE      1
 #define GSS_AUTH_P_INTEGRITY 2
@@ -47,11 +61,23 @@ display_status_1 (char *m, OM_uint32 code, int type)
   do
     {
       maj_stat = gss_display_status (&min_stat, code,
-				     type, GSS_C_NULL_OID, &msg_ctx, &msg);
-      syslog (LOG_ERR, _("GSS-API error %s: %s"), m, (char *) msg.value);
-      gss_release_buffer (&min_stat, &msg);
+				     type, GSS_C_NO_OID, &msg_ctx, &msg);
+      if (GSS_ERROR (maj_stat))
+	{
+	  asprintf ((char**)&msg.value, "code %d", code);
+	  msg.length = strlen (msg.value);
+	}
+
+      mu_diag_output (MU_DIAG_ERROR, _("GSS-API error %s (%s): %.*s"),
+	      m, type == GSS_C_GSS_CODE ? _("major") : _("minor"),
+	      (int) msg.length, (char *) msg.value);
+
+      if (GSS_ERROR (maj_stat))
+	free (msg.value);
+      else
+        gss_release_buffer (&min_stat, &msg);
     }
-  while (msg_ctx);
+  while (!GSS_ERROR (maj_stat) && msg_ctx);
 }
 
 static void
@@ -61,6 +87,7 @@ display_status (char *msg, OM_uint32 maj_stat, OM_uint32 min_stat)
   display_status_1 (msg, min_stat, GSS_C_MECH_CODE);
 }
 
+#ifndef WITH_GSS
 static int
 imap4d_gss_userok (gss_buffer_t client_name, char *name)
 {
@@ -79,6 +106,7 @@ imap4d_gss_userok (gss_buffer_t client_name, char *name)
   krb5_free_principal (kcontext, p);
   return rc;
 }
+#endif
 
 static int
 auth_gssapi (struct imap4d_command *command,
@@ -98,6 +126,7 @@ auth_gssapi (struct imap4d_command *command,
   gss_qop_t quality;
   gss_name_t client;
   gss_buffer_desc client_name;
+  int baduser;
 
   /* Obtain server credentials. RFC 1732 states, that 
      "The server must issue a ready response with no data and pass the
@@ -112,7 +141,7 @@ auth_gssapi (struct imap4d_command *command,
   tokbuf.value = tmp;
   tokbuf.length = strlen (tokbuf.value) + 1;
   maj_stat = gss_import_name (&min_stat, &tokbuf,
-			      gss_nt_service_name, &server_name);
+			      GSS_C_NT_HOSTBASED_SERVICE, &server_name);
   if (maj_stat != GSS_S_COMPLETE)
     {
       display_status ("import name", maj_stat, min_stat);
@@ -222,8 +251,8 @@ auth_gssapi (struct imap4d_command *command,
   mech = sec_level >> 24;
   if ((mech & SUPPORTED_P_MECH) == 0)
     {
-      syslog (LOG_NOTICE,
-	      _("client requested unsupported protection mechanism (%d)"),
+      mu_diag_output (MU_DIAG_NOTICE,
+	      _("Client requested unsupported protection mechanism (%d)"),
 	      mech);
       gss_release_buffer (&min_stat, &outbuf);
       maj_stat = gss_delete_sec_context (&min_stat, &context, &outbuf);
@@ -236,7 +265,7 @@ auth_gssapi (struct imap4d_command *command,
   *username = malloc (outbuf.length - 4 + 1);
   if (!*username)
     {
-      syslog (LOG_NOTICE, _("not enough memory"));
+      mu_diag_output (MU_DIAG_NOTICE, _("Not enough memory"));
       gss_release_buffer (&min_stat, &outbuf);
       maj_stat = gss_delete_sec_context (&min_stat, &context, &outbuf);
       gss_release_buffer (&min_stat, &outbuf);
@@ -257,9 +286,15 @@ auth_gssapi (struct imap4d_command *command,
       return RESP_NO;
     }
 
-  if (imap4d_gss_userok (&client_name, *username))
+#ifdef WITH_GSS
+  baduser = !gss_userok (client, *username);
+#else
+  baduser = imap4d_gss_userok (&client_name, *username);
+#endif
+
+  if (baduser)
     {
-      syslog (LOG_NOTICE, _("GSSAPI user %s is NOT authorized as %s"),
+      mu_diag_output (MU_DIAG_NOTICE, _("GSSAPI user %s is NOT authorized as %s"),
 	      (char *) client_name.value, *username);
       maj_stat = gss_delete_sec_context (&min_stat, &context, &outbuf);
       gss_release_buffer (&min_stat, &outbuf);
@@ -269,7 +304,7 @@ auth_gssapi (struct imap4d_command *command,
     }
   else
     {
-      syslog (LOG_NOTICE, _("GSSAPI user %s is authorized as %s"),
+      mu_diag_output (MU_DIAG_NOTICE, _("GSSAPI user %s is authorized as %s"),
 	      (char *) client_name.value, *username);
     }
 
