@@ -44,30 +44,20 @@ imap4d_login (struct imap4d_command *command, char *arg)
 
   if (auth_data == NULL)
     {
-      syslog (LOG_INFO, _("User `%s': nonexistent"), username);
+      mu_diag_output (MU_DIAG_INFO, _("User `%s': nonexistent"), username);
       return util_finish (command, RESP_NO, "User name or passwd rejected");
     }
 
   rc = mu_authenticate (auth_data, pass);
-  openlog ("gnu-imap4d", LOG_PID, log_facility);
+  openlog (MU_LOG_TAG (), LOG_PID, mu_log_facility);
   if (rc)
     {
-      syslog (LOG_INFO, _("Login failed: %s"), username);
+      mu_diag_output (MU_DIAG_INFO, _("Login failed: %s"), username);
       return util_finish (command, RESP_NO, "User name or passwd rejected");
     }
 
-  homedir = mu_normalize_path (strdup (auth_data->dir), "/");
-  if (imap4d_check_home_dir (homedir, auth_data->uid, auth_data->gid))
-    return util_finish (command, RESP_NO,
-			"User name or passwd rejected");
-        
-  if (auth_data->change_uid)
-    setuid (auth_data->uid);
-
-  util_chdir (homedir);
-    
-  namespace_init (homedir);
-  syslog (LOG_INFO, _("User `%s' logged in"), username);
+  if (imap4d_session_setup0 ())
+    return util_finish (command, RESP_NO, "User name or passwd rejected");
   return util_finish (command, RESP_OK, "Completed");
 }
 
