@@ -60,12 +60,12 @@ imap4d_lsub (struct imap4d_command *command, char *arg)
       char *buf = NULL;
       size_t n = 0;
 	
-      while (getline(&buf, &n, fp) > 0)
+      while (getline (&buf, &n, fp) > 0)
 	{
 	  int len = strlen (buf);
 	  if (buf[len - 1] == '\n')
 	    buf[len - 1] = '\0';
-	  if (util_wcard_match (buf, pattern, delim) != WCARD_NOMATCH)
+	  if (util_wcard_match (buf, pattern, delim) == 0)
 	    util_out (RESP_NONE, "LIST () \"%s\" %s", delim, buf);
 	}
       fclose (fp);
@@ -74,5 +74,5 @@ imap4d_lsub (struct imap4d_command *command, char *arg)
     }
   else if (errno == ENOENT)
     return util_finish (command, RESP_OK, "Completed");
-  return util_finish (command, RESP_NO, "Can not list subscriber");
+  return util_finish (command, RESP_NO, "Cannot list subscriber");
 }
