@@ -1,10 +1,11 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2005, 2006 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005, 2006, 
+   2007 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,8 +29,9 @@ extern "C" {
 #endif
 
 int mu_set_mail_directory (const char *p);
+int mu_set_mailbox_pattern (const char *pat);
 void mu_set_folder_directory (const char *p);
-const char *mu_mail_directory (void);
+const char *mu_mailbox_url (void);
 const char *mu_folder_directory (void);
 int mu_construct_user_mailbox_url (char **pout, const char *name);
 
@@ -51,13 +53,18 @@ extern int  mu_mailbox_uidvalidity     (mu_mailbox_t, unsigned long *);
 extern int  mu_mailbox_uidnext         (mu_mailbox_t, size_t *);
 
 /* Messages.  */
-extern int  mu_mailbox_get_message     (mu_mailbox_t, size_t msgno, mu_message_t *);
+extern int  mu_mailbox_get_message     (mu_mailbox_t, size_t msgno,
+					mu_message_t *);
+extern int  mu_mailbox_quick_get_message(mu_mailbox_t, mu_message_qid_t,
+					 mu_message_t *); 
 extern int  mu_mailbox_append_message  (mu_mailbox_t, mu_message_t);
 extern int  mu_mailbox_messages_count  (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_messages_recent (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_message_unseen  (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_expunge         (mu_mailbox_t);
-extern int  mu_mailbox_save_attributes (mu_mailbox_t);
+extern int  mu_mailbox_sync            (mu_mailbox_t);  
+extern int  mu_mailbox_save_attributes (mu_mailbox_t)
+                                       __attribute__ ((deprecated));
 
 /* Update and scanning.  */
 extern int  mu_mailbox_get_size        (mu_mailbox_t, mu_off_t *size);
