@@ -1,10 +1,11 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2004, 2005, 2006 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2004, 2005, 2006,
+   2007 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,7 +38,7 @@ struct _mu_record
   void *data; /* back pointer.  */
 
   /* Stub functions to override. The default is to return the fields.  */
-  int (*_is_scheme) (mu_record_t, const char *, int);
+  int (*_is_scheme) (mu_record_t, mu_url_t, int);
   int (*_get_url) (mu_record_t, int (*(*_mu_url)) (mu_url_t));
   int (*_get_mailbox) (mu_record_t, int (*(*_mu_mailbox)) (mu_mailbox_t));
   int (*_get_mailer) (mu_record_t, int (*(*_mu_mailer)) (mu_mailer_t));
@@ -50,16 +51,16 @@ extern int mu_registrar_get_list (mu_list_t *) __attribute__ ((deprecated));
   
 extern int mu_registrar_lookup (const char *name, int flags, 
                                 mu_record_t *precord, int *pflags);
-extern int mu_0_6_registrar_lookup (const char *name, mu_record_t *precord,
-				    int flags); 
+extern int mu_registrar_lookup_url (mu_url_t url, int flags,
+				    mu_record_t *precord, int *pflags);
 extern int mu_registrar_record       (mu_record_t);
 extern int mu_unregistrar_record     (mu_record_t);
 
 /* Scheme.  */
-extern int mu_record_is_scheme       (mu_record_t, const char *, int flags);
+extern int mu_record_is_scheme       (mu_record_t, mu_url_t, int flags);
 extern int mu_record_set_scheme      (mu_record_t, const char *);
 extern int mu_record_set_is_scheme   (mu_record_t, 
-                      int (*_is_scheme) (mu_record_t, const char *, int));
+                      int (*_is_scheme) (mu_record_t, mu_url_t, int));
 
 /* Url.  */
 extern int mu_record_get_url         (mu_record_t, int (*(*)) (mu_url_t));
@@ -87,8 +88,10 @@ extern int mu_record_set_get_folder  (mu_record_t,
 
 /* Remote Folder "imap://"  */
 extern mu_record_t mu_imap_record;
+extern mu_record_t mu_imaps_record;
 /* Remote Mailbox POP3, pop://  */
 extern mu_record_t mu_pop_record;
+extern mu_record_t mu_pops_record;
 /* Remote newsgroup NNTP, nntp://  */
 extern mu_record_t mu_nntp_record;
 
@@ -100,17 +103,20 @@ extern mu_record_t mu_path_record;
 extern mu_record_t mu_mh_record;
 /* Maildir, "maildir:" */
 extern mu_record_t mu_maildir_record;
-
-#define MU_IMAP_PRIO       100
-#define MU_POP_PRIO        200
-#define MU_MBOX_PRIO       300 
-#define MU_MH_PRIO         400
-#define MU_MAILDIR_PRIO    500 
-#define MU_NNTP_PRIO       600
-#define MU_PATH_PRIO       1000
-
-#define MU_SMTP_PRIO       10000
-#define MU_SENDMAIL_PRIO   10000
+/* Remote mailbox */
+extern mu_record_t mu_remote_mbox_record;
+  
+#define MU_IMAP_PRIO        100
+#define MU_POP_PRIO         200
+#define MU_MBOX_PRIO        300 
+#define MU_MH_PRIO          400
+#define MU_MAILDIR_PRIO     500 
+#define MU_NNTP_PRIO        600
+#define MU_PATH_PRIO        1000
+  
+#define MU_REMOTE_MBOX_PRIO 10000
+#define MU_SMTP_PRIO        10000
+#define MU_SENDMAIL_PRIO    10000
   
 /* SMTP mailer, "smtp://"  */
 extern mu_record_t mu_smtp_record;
@@ -121,7 +127,9 @@ extern mu_record_t mu_sendmail_record;
   mu_registrar_record (mu_path_record);\
   mu_registrar_record (mu_mbox_record);\
   mu_registrar_record (mu_pop_record);\
+  mu_registrar_record (mu_pops_record);\
   mu_registrar_record (mu_imap_record);\
+  mu_registrar_record (mu_imaps_record);\
   mu_registrar_record (mu_mh_record);\
   mu_registrar_record (mu_maildir_record);\
 } while (0)
@@ -135,7 +143,9 @@ extern mu_record_t mu_sendmail_record;
 
 #define mu_register_remote_mbox_formats() do {\
   mu_registrar_record (mu_pop_record);\
+  mu_registrar_record (mu_pops_record);\
   mu_registrar_record (mu_imap_record);\
+  mu_registrar_record (mu_imaps_record);\
   mu_registrar_record (mu_nntp_record);\
 } while (0)
 
