@@ -33,6 +33,9 @@
 extern "C" {
 #endif
 
+#define MU_FOLDER_LIST 0
+#define MU_FOLDER_ENUM 1
+  
 struct _mu_folder
 {
   /* Data */
@@ -55,29 +58,17 @@ struct _mu_folder
 
   int  (*_open)        (mu_folder_t, int flag);
   int  (*_close)       (mu_folder_t);
-  int  (*_list)        (mu_folder_t, const char *, const char *,
-			size_t,
-		        mu_list_t);
+  int  (*_list)        (mu_folder_t, const char *, void *, int, size_t,
+			mu_list_t, mu_folder_enumerate_fp, void *);
   int  (*_lsub)        (mu_folder_t, const char *, const char *,
 		        mu_list_t);
+  mu_folder_match_fp   _match;
   int  (*_delete)      (mu_folder_t, const char *);
   int  (*_rename)      (mu_folder_t, const char *, const char *);
   int  (*_subscribe)   (mu_folder_t, const char *);
   int  (*_unsubscribe) (mu_folder_t, const char *);
 };
 
-/* Moro(?)ic kluge.  */
-#define FOLDER_DEBUG0(folder, type, format) \
-if (folder->debug) mu_debug_print (folder->debug, type, format)
-#define FOLDER_DEBUG1(folder, type, format, arg1) \
-if (folder->debug) mu_debug_print (folder->debug, type, format, arg1)
-#define FOLDER_DEBUG2(folder, type, format, arg1, arg2) \
-if (folder->debug) mu_debug_print (folder->debug, type, format, arg1, arg2)
-#define FOLDER_DEBUG3(folder, type, format, arg1, arg2, arg3) \
-if (folder->debug) mu_debug_print (folder->debug, type, format, arg1, arg2, arg3)
-#define FOLDER_DEBUG4(folder, type, format, arg1, arg2, arg3, arg4) \
-if (folder->debug) mu_debug_print (folder->debug, type, format, arg1, arg2, arg3, arg4)
-
 #ifdef __cplusplus
 }
 #endif
