@@ -36,50 +36,60 @@ extern "C" {
    Perhaps they can be changed?
 */
 #define MU_POP_PORT 110
-#define MU_POP_SCHEME "pop://"
+#define MU_POP_SCHEME "pop"
 #define MU_POP_SCHEME_LEN (sizeof (MU_POP_SCHEME) - 1)
 extern int _url_pop_init          (mu_url_t);
 extern int _mailbox_pop_init      (mu_mailbox_t);
 extern int _folder_pop_init       (mu_folder_t);
 
+#define MU_POPS_PORT 995
+#define MU_POPS_SCHEME "pops"
+#define MU_POPS_SCHEME_LEN (sizeof (MU_POPS_SCHEME) - 1)
+extern int _url_pops_init         (mu_url_t);
+extern int _mailbox_pops_init     (mu_mailbox_t);
+
 #define MU_IMAP_PORT 143
-#define MU_IMAP_SCHEME "imap://"
+#define MU_IMAP_SCHEME "imap"
 #define MU_IMAP_SCHEME_LEN (sizeof (MU_IMAP_SCHEME) - 1)
 extern int _url_imap_init         (mu_url_t);
 extern int _mailbox_imap_init     (mu_mailbox_t);
 extern int _folder_imap_init      (mu_folder_t);
 
-#define MU_MBOX_SCHEME "mbox:"
+#define MU_IMAPS_PORT 993
+#define MU_IMAPS_SCHEME "imaps"
+#define MU_IMAPS_SCHEME_LEN (sizeof (MU_IMAPS_SCHEME) - 1)
+extern int _url_imaps_init        (mu_url_t);
+extern int _mailbox_imaps_init    (mu_mailbox_t);
+
+#define MU_MBOX_SCHEME "mbox"
 #define MU_MBOX_SCHEME_LEN (sizeof (MU_MBOX_SCHEME) - 1)
-extern int _url_mbox_init         (mu_url_t);
 extern int _mailbox_mbox_init     (mu_mailbox_t);
 extern int _folder_mbox_init      (mu_folder_t);
 
-#define MU_FILE_SCHEME "file:"
+#define MU_FILE_SCHEME "file"
 #define MU_FILE_SCHEME_LEN (sizeof (MU_FILE_SCHEME) - 1)
 
 #define MU_PATH_SCHEME "/"
 #define MU_PATH_SCHEME_LEN (sizeof (MU_PATH_SCHEME) - 1)
-extern int _url_path_init         (mu_url_t);
 extern int _mailbox_path_init     (mu_mailbox_t);
 extern int _folder_path_init      (mu_folder_t);
 
-#define MU_SMTP_SCHEME "smtp://"
+#define MU_SMTP_SCHEME "smtp"
 #define MU_SMTP_SCHEME_LEN (sizeof (MU_SMTP_SCHEME) - 1)
 #define MU_SMTP_PORT 25
 extern int _url_smtp_init         (mu_url_t);
 extern int _mailer_smtp_init      (mu_mailer_t);
 
-#define MU_SENDMAIL_SCHEME "sendmail:"
+#define MU_SENDMAIL_SCHEME "sendmail"
 #define MU_SENDMAIL_SCHEME_LEN (sizeof (MU_SENDMAIL_SCHEME) - 1)
 extern int _url_sendmail_init     (mu_url_t);
 extern int _mailer_sendmail_init  (mu_mailer_t);
 
-#define MU_MH_SCHEME "mh:"
+#define MU_MH_SCHEME "mh"
 #define MU_MH_SCHEME_LEN (sizeof (MU_MH_SCHEME) - 1)
 extern int _mailbox_mh_init (mu_mailbox_t mailbox);
 
-#define MU_MAILDIR_SCHEME "maildir:"
+#define MU_MAILDIR_SCHEME "maildir"
 #define MU_MAILDIR_SCHEME_LEN (sizeof (MU_MAILDIR_SCHEME) - 1)
 extern int _mailbox_maildir_init (mu_mailbox_t mailbox);
 
