@@ -1,10 +1,11 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005, 2006,
+   2007 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,7 +32,7 @@ typedef union {
   mu_sieve_value_t *val;
   mu_list_t list;
   long number;
-  char *string;
+  const char *string;
   size_t pc;
   size_t line;
 } sieve_op_t;
@@ -59,7 +60,7 @@ struct sieve_machine {
 
   int debug_level;           /* Debugging level */
   jmp_buf errbuf;            /* Target location for non-local exits */
-  char *identifier;          /* Name of action or test being executed */
+  const char *identifier;    /* Name of action or test being executed */
   
   mu_mailbox_t mailbox;      /* Mailbox to operate upon */
   size_t    msgno;           /* Current message number */
@@ -88,9 +89,9 @@ extern int sieve_error_count;
 #define TAG_RELFUN  "__relfun__"
 
 void sieve_compile_error (const char *filename, int linenum,
-			  const char *fmt, ...);
+			  const char *fmt, ...) MU_PRINTFLIKE(3,4);
 void sieve_debug_internal (mu_sieve_printf_t printer, void *data,
-			   const char *fmt, ...);
+			   const char *fmt, ...) MU_PRINTFLIKE(3,4);
 void sieve_print_value (mu_sieve_value_t *val, mu_sieve_printf_t printer,
 		        void *data);
 void sieve_print_value_list (mu_list_t list, mu_sieve_printf_t printer, void *data);
