@@ -1,11 +1,11 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2005, 2006 Free Software Foundation, Inc.
+   2005, 2006, 2007 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -35,6 +35,7 @@
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/time.h>
 #include <sys/wait.h>
 #include <sys/select.h>
 
@@ -43,6 +44,8 @@
 #endif
 
 #include <mailutils/address.h>
+#include <mailutils/assoc.h>
+#include <mailutils/argcv.h>
 #include <mailutils/error.h>
 #include <mailutils/errno.h>
 #include <mailutils/iterator.h>
@@ -55,6 +58,8 @@
 #include <mailutils/nls.h>
 #include <mailutils/stream.h>
 #include <mailutils/filter.h>
+#include <mailutils/sql.h>
+#include <mailutils/url.h>
 
 #include <registrar0.h>
 
@@ -352,7 +357,7 @@ mu_set_user_email (const char *candidate)
   mu_address_t addr = NULL;
   size_t emailno = 0;
   char *email = NULL;
-  char *domain = NULL;
+  const char *domain = NULL;
   
   if ((err = mu_address_create (&addr, candidate)) != 0)
     return err;
@@ -374,9 +379,8 @@ mu_set_user_email (const char *candidate)
 
   mu_user_email = email;
 
-  mu_address_aget_domain (addr, 1, &domain);
-  mu_set_user_email_domain (domain);
-  free (domain);
+  if ((err = mu_address_sget_domain (addr, 1, &domain)) == 0)
+    mu_set_user_email_domain (domain);
   
 cleanup:
   mu_address_destroy (&addr);
@@ -389,7 +393,7 @@ static char *mu_user_email_domain = 0;
 int
 mu_set_user_email_domain (const char *domain)
 {
-  char* d = NULL;
+  char *d = NULL;
   
   if (!domain)
     return EINVAL;
@@ -549,35 +553,6 @@ mu_normalize_path (char *path, const char *delim)
   return path;
 }
 
-int
-mu_normalize_mailbox_url (char **pout, const char *dir)
-{
-  int len;
-
-  if (!pout)
-    return MU_ERR_OUT_PTR_NULL;
-      
-  len = strlen (dir);
-  if (dir[len-1] == '/')
-    *pout = strdup (dir);
-  else if (strncasecmp (dir, "mbox:", 5) == 0 && dir[len-1] == '=')
-    {
-      if (len > 5 && strcmp (dir + len - 5, "user=") == 0)
-	*pout = strdup (dir);
-      else
-	return MU_ERR_BAD_FILENAME;
-    }
-  else
-    {
-      *pout = malloc (strlen (dir) + 2);
-      if (*pout)
-	strcat (strcpy (*pout, dir), "/");
-    }
-
-  /* Final check */
-  return (*pout == NULL) ? errno : 0;
-}
-
 /* Create and open a temporary file. Be very careful about it, since we
    may be running with extra privilege i.e setgid().
    Returns file descriptor of the open file.
@@ -655,7 +630,7 @@ mu_tempname (const char *tmpdir)
  * to find it.
  */
 int 
-mu_spawnvp (const char *prog, char * const av[], int *stat)
+mu_spawnvp (const char *prog, char *av[], int *stat)
 {
   pid_t pid;
   int err = 0;
@@ -1022,6 +997,35 @@ mu_rfc2822_references (mu_message_t msg, char **pstr)
   return MU_ERR_FAILURE;
 }
 
+int
+mu_rfc2822_msg_id (int subpart, char **pval)
+{
+  char date[4+2+2+2+2+2+1];
+  time_t t = time (NULL);
+  struct tm *tm = localtime (&t);
+  char *host;
+  char *p;
+	  
+  mu_strftime (date, sizeof date, "%Y%m%d%H%M%S", tm);
+  mu_get_host_name (&host);
+
+  if (subpart)
+    {
+      struct timeval tv;
+      gettimeofday (&tv, NULL);
+      asprintf (&p, "<%s.%lu.%d@%s>",
+		date,
+		(unsigned long) getpid (),
+		subpart,
+		host);
+    }
+  else
+    asprintf (&p, "<%s.%lu@%s>", date, (unsigned long) getpid (), host);
+  free (host);
+  *pval = p;
+  return 0;
+}
+
 #define DATEBUFSIZE 128
 #define COMMENT "Your message of "
 
@@ -1037,7 +1041,8 @@ mu_rfc2822_references (mu_message_t msg, char **pstr)
 int
 mu_rfc2822_in_reply_to (mu_message_t msg, char **pstr)
 {
-  char *value, *s1 = NULL, *s2 = NULL;
+  const char *value = NULL;
+  char *s1 = NULL, *s2 = NULL;
   mu_header_t hdr;
   int rc;
   
@@ -1045,39 +1050,30 @@ mu_rfc2822_in_reply_to (mu_message_t msg, char **pstr)
   if (rc)
     return rc;
   
-  if (mu_header_aget_value (hdr, MU_HEADER_DATE, &value))
+  if (mu_header_sget_value (hdr, MU_HEADER_DATE, &value))
     {
       mu_envelope_t envelope = NULL;
-      value = malloc (DATEBUFSIZE);
-      if (value)
-	{
-	  mu_message_get_envelope (msg, &envelope);
-	  mu_envelope_date (envelope, value, DATEBUFSIZE, NULL);
-	}
+      mu_message_get_envelope (msg, &envelope);
+      mu_envelope_sget_date (envelope, &value);
     }
 
   if (value)
     {
       s1 = malloc (sizeof (COMMENT) + strlen (value));
-      if (s1)
-	strcat (strcpy (s1, COMMENT), value);
-      free (value);
       if (!s1)
 	return ENOMEM;
+      strcat (strcpy (s1, COMMENT), value);
     }
   
-  if (mu_header_aget_value (hdr, MU_HEADER_MESSAGE_ID, &value) == 0)
+  if (mu_header_sget_value (hdr, MU_HEADER_MESSAGE_ID, &value) == 0)
     {
       s2 = malloc (strlen (value) + 3);
-      if (s2)
-	strcat (strcpy (s2, "\n\t"), value);
-	  
-      free (value);
       if (!s2)
 	{
 	  free (s1);
 	  return ENOMEM;
 	}
+      strcat (strcpy (s2, "\n\t"), value);
     }
 
   if (s1 || s2)
@@ -1248,36 +1244,33 @@ mu_true_answer_p (const char *p)
   return -1;
 }
 
-/* Returns true if SCHEME represents a local mail folder. Stores
-   real folder path to PATH */
+/* Returns true if SCHEME represents a local (autodetect) mail folder.  */
 int
-mu_scheme_autodetect_p (const char *scheme,  const char **path)
+mu_scheme_autodetect_p (mu_url_t url)
 {
-  *path = scheme;
-  if (strncmp (MU_FILE_SCHEME, scheme, MU_FILE_SCHEME_LEN) == 0)
+  if (mu_url_is_scheme (url, "file"))
     {
-      *path += MU_FILE_SCHEME_LEN;
+      mu_url_expand_path (url);
       return 1;
     }
-  if (access (scheme, F_OK) == 0
-      /* FIXME: this can return true even if the folder is unreadable */
-      || strncmp (MU_PATH_SCHEME, scheme, MU_PATH_SCHEME_LEN) == 0)
-    return 1;
   return 0;
 }
     
 int
 mu_fd_wait (int fd, int *pflags, struct timeval *tvp)
 {
-  fd_set rdset, wrset;
+  fd_set rdset, wrset, exset;
   int rc;
 
   FD_ZERO (&rdset);
   FD_ZERO (&wrset);
+  FD_ZERO (&exset);
   if ((*pflags) & MU_STREAM_READY_RD)
     FD_SET (fd, &rdset);
   if ((*pflags) & MU_STREAM_READY_WR)
     FD_SET (fd, &wrset);
+  if ((*pflags) & MU_STREAM_READY_EX)
+    FD_SET (fd, &exset);
   
   do
     {
@@ -1301,6 +1294,8 @@ mu_fd_wait (int fd, int *pflags, struct timeval *tvp)
 	*pflags |= MU_STREAM_READY_RD;
       if (FD_ISSET (fd, &wrset))
 	*pflags |= MU_STREAM_READY_WR;
+      if (FD_ISSET (fd, &exset))
+	*pflags |= MU_STREAM_READY_EX;
     }
   return 0;
 }
@@ -1329,7 +1324,7 @@ mu_decode_filter (mu_stream_t *pfilter, mu_stream_t input,
   mu_stream_t filter;
   
   int status = mu_filter_create (&filter, input, filter_type,
-			      MU_FILTER_DECODE, MU_STREAM_READ);
+				 MU_FILTER_DECODE, MU_STREAM_READ);
   if (status)
     return status;
 
@@ -1397,4 +1392,81 @@ mu_strftime (char *s, size_t max, const char *format, const struct tm *tm)
   return size;
 }
   
-    
+
+static void
+assoc_str_free (void *data)
+{
+  free (data);
+}
+
+int
+mutil_parse_field_map (const char *map, mu_assoc_t *passoc_tab, int *perr)
+{
+  int rc;
+  int i;
+  int argc;
+  char **argv;
+  mu_assoc_t assoc_tab = NULL;
+
+  rc = mu_argcv_get (map, ":", NULL, &argc, &argv);
+  if (rc)
+    {
+      mu_error (_("cannot split line `%s': %s"), map, mu_strerror (rc));
+      return rc;
+    }
+
+  for (i = 0; i < argc; i += 2)
+    {
+      char *tok = argv[i];
+      char *p = strchr (tok, '=');
+      char *pptr;
+      
+      if (!p)
+	{
+	  rc = EINVAL;
+	  break;
+	}
+      if (!assoc_tab)
+	{
+	  rc = mu_assoc_create (&assoc_tab, sizeof(char*), 0);
+	  if (rc)
+	    break;
+	  mu_assoc_set_free (assoc_tab, assoc_str_free);
+	  *passoc_tab = assoc_tab;
+	}
+      *p++ = 0;
+      pptr = strdup (p);
+      if (!pptr)
+	{
+	  rc = errno;
+	  break;
+	}
+      rc = mu_assoc_install (assoc_tab, tok, &pptr);
+      if (rc)
+	{
+	  free (p);
+	  break;
+	}
+    }
+
+  mu_argcv_free (argc, argv);
+  if (rc && perr)
+    *perr = i;
+  return rc;
+}
+
+/* FIXME: should it be here? */
+int
+mu_sql_decode_password_type (const char *arg, enum mu_password_type *t)
+{
+  if (strcmp (arg, "plain") == 0)
+    *t = password_plaintext;
+  else if (strcmp (arg, "hash") == 0)
+    *t = password_hash;
+  else if (strcmp (arg, "scrambled") == 0)
+    *t = password_scrambled;
+  else
+    return 1;
+  return 0;
+}
+
