@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2005, 2007, 2008 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,6 +25,11 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 
+#include "mailutils/libargp.h"
+#include "mailutils/argcv.h"
+
+#include "mailcap.h"
+
 const char *program_version = "mimeview (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU mimeview -- display files, using mailcap mechanism.")
 "\v"     
@@ -63,9 +68,32 @@ static int interactive = -1;
 char *mimeview_file;       /* Name of the file to view */
 FILE *mimeview_fp;     /* Its descriptor */
 
+static void
+set_debug_flags (mu_debug_t debug, char *arg)
+{
+  for (; *arg; arg++)
+    {
+      switch (*arg)
+	{
+	case 'l':
+	  mimetypes_lex_debug (1);
+	  break;
+
+	case 'g':
+	  mimetypes_gram_debug (1);
+	  break;
+	  
+	default:
+	  debug_level = *arg - '0';
+	}
+    }
+}  
+
 static error_t
 parse_opt (int key, char *arg, struct argp_state *state)
 {
+  static struct mu_argp_node_list lst;
+
   switch (key)
     {
     case ARGP_KEY_INIT:
@@ -73,11 +101,13 @@ parse_opt (int key, char *arg, struct argp_state *state)
       mimetypes_gram_debug (0);
       if (interactive == -1)
 	interactive = isatty (fileno (stdin));
+      mu_argp_node_list_init (&lst);
       break;
 
     case ARGP_KEY_FINI:
       if (dry_run && !debug_level)
 	debug_level = 1;
+      mu_argp_node_list_finish (&lst, NULL, NULL);
       break;
 
     case 'a':
@@ -86,24 +116,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
       break;
       
     case 'd':
-      if (!arg)
-	arg = "9";
-      for (; *arg; arg++)
-	{
-	  switch (*arg)
-	    {
-	    case 'l':
-	      mimetypes_lex_debug (1);
-	      break;
-
-	    case 'g':
-	      mimetypes_gram_debug (1);
-	      break;
-
-	    default:
-	      debug_level = *arg - '0';
-	    }
-	}
+      mu_argp_node_list_new (&lst, "debug", arg ? arg : "9");
       break;
 
     case 'h':
@@ -115,11 +128,11 @@ parse_opt (int key, char *arg, struct argp_state *state)
       break;
       
     case 't':
-      mimetypes_config = arg;
+      mu_argp_node_list_new (&lst, "mimetypes", arg);
       break;
 
     case OPT_METAMAIL:
-      metamail = arg ? arg : "metamail";
+      mu_argp_node_list_new (&lst, "metamail", arg ? arg : "metamail");
       break;
       
     default: 
@@ -137,8 +150,39 @@ static struct argp argp = {
   NULL, NULL
 };
 
+
+static int
+cb_debug (mu_debug_t debug, void *data, char *arg)
+{
+  set_debug_flags (debug, arg);
+  return 0;
+}
+
+static int
+cb_metamail (mu_debug_t debug, void *data, char *arg)
+{
+  metamail = strdup ("metamail");
+  return 0;
+}
+
+struct mu_cfg_param mimeview_cfg_param[] = {
+  { "debug", mu_cfg_callback, NULL, 0, cb_debug,
+    N_("Set debug verbosity level."),
+    N_("flags") },
+  { "mimetypes", mu_cfg_string, &mimetypes_config, 0, NULL,
+    N_("Use this mime.types file."),
+    N_("file") },
+  { "metamail", mu_cfg_string, NULL, 0, cb_metamail,
+    N_("Use this program to display files."),
+    N_("prog") },
+  { NULL }
+};
+
+
+
 static const char *capa[] = {
   "common",
+  "debug",
   "license",
   NULL
 };
@@ -181,7 +225,7 @@ display_file (const char *type)
   
   if (metamail)
     {
-      const char *argv[7];
+      char *argv[7];
       
       argv[0] = "metamail";
       argv[1] = "-b";
@@ -189,7 +233,7 @@ display_file (const char *type)
       argv[2] = interactive ? "-p" : "-h";
       
       argv[3] = "-c";
-      argv[4] = type;
+      argv[4] = (char*) type;
       argv[5] = mimeview_file;
       argv[6] = NULL;
       
@@ -237,9 +281,11 @@ main (int argc, char **argv)
 {
   int index;
   
-  mu_init_nls ();
+  MU_APP_INIT_NLS ();
   mu_argp_init (program_version, NULL);
-  mu_argp_parse (&argp, &argc, &argv, 0, capa, &index, NULL);
+  if (mu_app_init (&argp, capa, mimeview_cfg_param, 
+		   argc, argv, 0, &index, NULL))
+    exit (1);
 
   argc -= index;
   argv += index;
